'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

var breakpoints = [
	{
		breakpoint: "xs",
		abbr: "",
		name: "Extra small",
		"min-width": "0px",
		container: ""
	},
	{
		breakpoint: "sm",
		abbr: "-sm",
		name: "Small",
		"min-width": "576px",
		container: "540px"
	},
	{
		breakpoint: "md",
		abbr: "-md",
		name: "Medium",
		"min-width": "768px",
		container: "720px"
	},
	{
		breakpoint: "lg",
		abbr: "-lg",
		name: "Large",
		"min-width": "992px",
		container: "960px"
	},
	{
		breakpoint: "xl",
		abbr: "-xl",
		name: "Extra large",
		"min-width": "1200px",
		container: "1140px"
	}
];
var colors = [
	{
		name: "blue",
		hex: "#007bff"
	},
	{
		name: "indigo",
		hex: "#6610f2"
	},
	{
		name: "purple",
		hex: "#6f42c1"
	},
	{
		name: "pink",
		hex: "#e83e8c"
	},
	{
		name: "red",
		hex: "#dc3545"
	},
	{
		name: "orange",
		hex: "#fd7e14"
	},
	{
		name: "yellow",
		hex: "#ffc107"
	},
	{
		name: "green",
		hex: "#28a745"
	},
	{
		name: "teal",
		hex: "#20c997"
	},
	{
		name: "cyan",
		hex: "#17a2b8"
	},
	{
		name: "white",
		hex: "#fff"
	},
	{
		name: "gray",
		hex: "#868e96"
	},
	{
		name: "gray-dark",
		hex: "#343a40"
	}
];
var json = {
	breakpoints: breakpoints,
	colors: colors,
	"theme-colors": [
	{
		name: "primary",
		hex: "#007bff"
	},
	{
		name: "secondary",
		hex: "#868e96"
	},
	{
		name: "success",
		hex: "#28a745"
	},
	{
		name: "danger",
		hex: "#dc3545"
	},
	{
		name: "warning",
		hex: "#ffc107"
	},
	{
		name: "info",
		hex: "#17a2b8"
	},
	{
		name: "light",
		hex: "#f8f9fa"
	},
	{
		name: "dark",
		hex: "#343a40"
	}
]
};

function arraify(value) {
  return Array.isArray(value) ? value : [value];
}
function dedupe(list) {
  if (!Array.isArray(list)) throw new Error("muse be list!");
  return Array.from(new Set(list));
}
function flatten(listOrItem) {
  var newList = [];

  if (Array.isArray(listOrItem)) {
    listOrItem.forEach(function (item) {
      newList = newList.concat(flatten(item));
    });
  } else newList.push(listOrItem);

  return newList;
}

function rclassnames(props) {
  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  var clsList = dedupe(flatten(args).concat([props.className, props["class"]]).filter(function (x) {
    return x && typeof x === 'string';
  }).map(function (x) {
    return x && x.trim();
  }).join(' ').split(' '));
  if (!clsList.length) return;
  return clsList.join(' ');
}

var themes = json['theme-colors'].map(function (theme) {
  return theme.name;
});
var sizes = json['breakpoints'].map(function (x) {
  return x.breakpoint;
}).filter(function (x) {
  return x;
});
function resolveJSXElement(inputJSXElement) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref$default = _ref["default"],
      defaultValue = _ref$default === void 0 ? React.Fragment : _ref$default,
      _ref$allowedHTMLTags = _ref.allowedHTMLTags,
      allowedHTMLTags = _ref$allowedHTMLTags === void 0 ? undefined : _ref$allowedHTMLTags;

  if (!inputJSXElement) return defaultValue;

  if (allowedHTMLTags && typeof inputJSXElement === 'string') {
    inputJSXElement = inputJSXElement.toString();
    allowedHTMLTags = arraify(allowedHTMLTags).filter(function (x) {
      return typeof x === 'string';
    }).map(function (x) {
      return x.toString();
    });
    if (allowedHTMLTags.length && !allowedHTMLTags.includes(inputJSXElement)) throw new Error("[resolveJSXElement] inputJSXElement must be valid string: ".concat(allowedHTMLTags.join(', '), "; but ").concat(inputJSXElement, " given!"));
  }

  return inputJSXElement;
}

/**
 * @see https://getbootstrap.com/docs/4.4/components/button-group
 */

function ButtonGroup(_a) {
  var children = _a.children,
      _b = _a.as,
      _as = _b === void 0 ? 'div' : _b,
      size = _a.size,
      _c = _a.vertical,
      vertical = _c === void 0 ? false : _c,
      _d = _a.toggle,
      toggle = _d === void 0 ? false : _d,
      props = __rest(_a, ["children", "as", "size", "vertical", "toggle"]);

  var JSXEl = resolveJSXElement(_as, {
    allowedHTMLTags: ['div']
  });

  switch (size) {
    case 'lg':
    case 'sm':
      break;

    default:
      size = undefined;
      break;
  }

  return React.createElement(JSXEl, _extends({}, props, {
    className: rclassnames(props, ["btn-group" + (vertical ? '-vertical' : ''), size && "btn-group-" + size, toggle && "btn-group-toggle"]),
    role: "group"
  }), children);
}

module.exports = ButtonGroup;
